@@ -541,7 +541,7 @@ const Identity &IdentityManager::identityForAddress(
     const QString &addresses) const
 {
     const QStringList addressList = KEmailAddress::splitAddressList(addresses);
-    foreach (const QString &fullAddress, addressList) {
+    for (const QString &fullAddress : addressList) {
         const QString addrSpec = KEmailAddress::extractEmailAddress(fullAddress).toLower();
         for (ConstIterator it = begin(); it != end(); ++it) {
             const Identity &identity = *it;
@@ -606,8 +606,9 @@ bool IdentityManager::setAsDefault(uint uoid)
 {
     // First, check if the identity actually exists:
     bool found = false;
+    ConstIterator end(d->shadowIdentities.constEnd());
     for (ConstIterator it = d->shadowIdentities.constBegin();
-            it != d->shadowIdentities.constEnd(); ++it) {
+            it != end; ++it) {
         if ((*it).uoid() == uoid) {
             found = true;
             break;
